# Cythonization Report

This report summarizes the Cythonization percentage for various source files, indicating the level of Python interaction within the compiled code.

## Overall Summary

Metric | Value
--- | ---
Total Score Sum | 7389.0
Possible Score | 111700.0
Total Non-Empty Lines | 1117.0
Python Overhead Lines | 439.0
Overall Cythonization Percentage | 93.38%
Overall Python Overhead Lines Percentage | 39.3%

## File: euler_engine.html

Metric | Value
--- | ---
Total Score Sum | 64
Possible Score | 1600
Total Non-Empty Lines | 16
Python Overhead Lines | 4
Cythonization Percentage | 96.0%
Python Overhead Lines Percentage | 25.0%

## File: _test_helpers.html

Metric | Value
--- | ---
Total Score Sum | 1412
Possible Score | 11300
Total Non-Empty Lines | 113
Python Overhead Lines | 43
Cythonization Percentage | 87.5%
Python Overhead Lines Percentage | 38.05%

## File: base_engine.html

Metric | Value
--- | ---
Total Score Sum | 1362
Possible Score | 43900
Total Non-Empty Lines | 439
Python Overhead Lines | 115
Cythonization Percentage | 96.9%
Python Overhead Lines Percentage | 26.2%

## File: traj_data.html

Metric | Value
--- | ---
Total Score Sum | 2854
Possible Score | 22700
Total Non-Empty Lines | 227
Python Overhead Lines | 146
Cythonization Percentage | 87.43%
Python Overhead Lines Percentage | 64.32%

## File: bind.html

Metric | Value
--- | ---
Total Score Sum | 783
Possible Score | 19900
Total Non-Empty Lines | 199
Python Overhead Lines | 92
Cythonization Percentage | 96.07%
Python Overhead Lines Percentage | 46.23%

## File: _test_engine.html

Metric | Value
--- | ---
Total Score Sum | 850
Possible Score | 10700
Total Non-Empty Lines | 107
Python Overhead Lines | 35
Cythonization Percentage | 92.06%
Python Overhead Lines Percentage | 32.71%

## File: rk4_engine.html

Metric | Value
--- | ---
Total Score Sum | 64
Possible Score | 1600
Total Non-Empty Lines | 16
Python Overhead Lines | 4
Cythonization Percentage | 96.0%
Python Overhead Lines Percentage | 25.0%